import { createElement, Component, createRef, Fragment } from 'react';
import * as Script from 'react-load-script';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var ReactMatiLoader = (function (_super) {
    __extends(ReactMatiLoader, _super);
    function ReactMatiLoader(props) {
        var _this = _super.call(this, props) || this;
        var documentScripts = document.getElementsByTagName('script');
        _this.loadScript = false;
        for (var i = 0; i < documentScripts.length; i += 1) {
            if (documentScripts[i].src.includes('https://sdk.getmati.com/mati-sdk.min.js')) {
                _this.loadScript = false;
            }
        }
        return _this;
    }
    ReactMatiLoader.prototype.componentDidMount = function () {
        var onLoad = this.props.onLoad;
        if (onLoad && this.loadScript === false) {
            onLoad();
        }
    };
    ReactMatiLoader.prototype.render = function () {
        var _a = this.props, onError = _a.onError, onLoad = _a.onLoad;
        if (this.loadScript === true) {
            return (createElement(Script, { attributes: { id: 'matiscript' }, url: "https://sdk.getmati.com/mati-sdk.min.js", onError: onError, onLoad: onLoad }));
        }
        return null;
    };
    return ReactMatiLoader;
}(Component));

var ReactMati = (function (_super) {
    __extends(ReactMati, _super);
    function ReactMati(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            hasError: false,
            loadingStatus: 'loading',
            errorElement: undefined,
        };
        _this.onLoad = function () {
            var _a = _this.props, clientId = _a.clientId, metadata = _a.metadata, hideChat = _a.hideChat;
            var Mati = window.Mati;
            if (Mati) {
                _this.setState({ loadingStatus: 'ready' });
                Mati.render({
                    clientId: clientId,
                    metadata: metadata,
                    hideChat: hideChat,
                    element: _this.matiButton.current,
                });
            }
        };
        _this.onError = function () {
            _this.setState({ loadingStatus: 'errored' });
        };
        _this.matiButton = createRef();
        return _this;
    }
    ReactMati.prototype.componentDidCatch = function (error, info) {
        this.setState({ loadingStatus: 'errored' });
    };
    ReactMati.prototype.render = function () {
        var _a = this.state, loadingStatus = _a.loadingStatus, errorElement = _a.errorElement;
        var _b = this.props, children = _b.children, product = _b.product, country = _b.country, style = _b.style;
        var component = null;
        if (loadingStatus === 'errored') {
            component = errorElement || 'Error loading Mati';
        }
        else {
            component = createElement(ReactMatiLoader, { onLoad: this.onLoad, onError: this.onError });
        }
        return (createElement(Fragment, null,
            createElement("div", { ref: this.matiButton, className: "mati-button responsive", "data-product": product, "data-country": country, "data-style": style }),
            component));
    };
    ReactMati.defaultProps = {
        clientId: undefined,
        metadata: {},
        hideChat: false,
        product: 'kyc',
        country: 'us',
        style: 'blue',
    };
    return ReactMati;
}(Component));

export default ReactMati;
export { ReactMati };
